@@ -1985,11 +1985,11 @@ int poolid;
     }
 
     if (ret)
-#ifdef NO_MEMCPY
+#ifdef NO_MEMMOVE
 	bcopy(s, ret+hdr, size-hdr);
 #else
-	memcpy(ret+hdr, s, size-hdr);
-#endif /* NO_MEMCPY */
+	memmove(ret+hdr, s, size-hdr);
+#endif /* NO_MEMMOVE */
 
     return ret;
 }
